@@ -4,7 +4,6 @@
 
 #include "deepinwmfaker.h"
 
-#include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDebug>
 #include <QJsonArray>
@@ -14,22 +13,22 @@
 #include <QProcess>
 #include <QStringList>
 #include <QFileInfo>
-#include <QDBusReply>
 #include <QMetaEnum>
+#include <QDBusConnectionInterface>
 #include <mutex>
 
-#include <KF5/KConfigCore/KConfig>
-#include <KF5/KConfigCore/KConfigGroup>
-#include <KF5/KConfigCore/KSharedConfig>
-#include <KF5/KWindowSystem/KWindowSystem>
-#include <KF5/KWindowSystem/KWindowEffects>
-#include <KF5/KGlobalAccel/KGlobalAccel>
+#include <KF6/KConfigCore/KConfigGroup>
+#include <KF6/KConfigCore/KSharedConfig>
+#include <KF6/KGlobalAccel/KGlobalAccel>
+#include <KF6/KWindowSystem/KWindowSystem>
+#include <KF6/KWindowSystem/KWindowEffects>
+#include <KWindowInfo>
+#include <KX11Extras>
+
+#include <DConfig>
 
 #ifndef DISABLE_DEEPIN_WM
-#include <QGSettings>
-Q_GLOBAL_STATIC_WITH_ARGS(QGSettings, _gsettings_dde_appearance, ("com.deepin.dde.appearance"))
-Q_GLOBAL_STATIC_WITH_ARGS(QGSettings, _gsettings_dde_zone, ("com.deepin.dde.zone"))
-#define GsettingsBackgroundUri "backgroundUris"
+#define DconfigBackgroundUri "Background_Uris"
 #define GsettingsZoneRightUp "rightUp"
 #define GsettingsZoneRightDown "rightDown"
 #define GsettingsZoneLeftDown "leftDown"
@@ -40,11 +39,11 @@ Q_GLOBAL_STATIC_WITH_ARGS(QGSettings, _gsettings_dde_zone, ("com.deepin.dde.zone
 #define DeepinWMGeneralGroupName "General"
 #define DeepinWMWorkspaceBackgroundGroupName "WorkspaceBackground"
 
-#define KWinConfigName "deepin-kwinrc"
+#define KWinConfigName "kwinrc"
 #define KWinCloseWindowGroupName "Script-closewindowaction"
 #define KWinRunCommandGroupName "Script-runcommandaction"
 
-#define GlobalAccelComponentName "deepin-kwin"
+#define GlobalAccelComponentName "kwin"
 #define GlobalAccelComponentDisplayName "KWin"
 
 // kwin dbus
@@ -117,6 +116,9 @@ static QMap<QString, QString> AllDeepinWMKWinAccelsMap {
     { "expose-all-windows", "ExposeAll" },
     { "expose-windows", "Expose" },
     { "preview-workspace", "ShowMultitasking" },
+    { "view-zoom-in", "view_zoom_in" },
+    { "view-zoom-out", "view_zoom_out" },
+    { "view-actual-size", "view_actual_size" },
 };
 
 static const QMap<QString, QString> WaylandDeepinWMKWinAccelsMap {
@@ -319,33 +321,25 @@ DeepinWMFaker::DeepinWMFaker(QObject* appearance)
 {
     m_workspaceount =  QDBusInterface(KWinDBusService, "/VirtualDesktopManager", "org.kde.KWin.VirtualDesktopManager").property("count").value<int>();
     m_isPlatformX11 = isX11Platform();
+    m_appearance = QSharedPointer<DConfig>(DConfig::create("org.deepin.dde.appearance", "org.deepin.dde.appearance"));
+    if (!m_appearance || !m_appearance->isValid()) {
+        qWarning() << "appearance dconfig is not vaild";
+        exit(-1);
+    }
 #ifndef DISABLE_DEEPIN_WM
     m_currentDesktop = m_kwinConfig->group("Workspace").readEntry<int>("CurrentDesktop", 1);
 
-    connect(m_windowSystem, &KWindowSystem::currentDesktopChanged, this, [this] (int to) {
+    connect(KX11Extras::self(), &KX11Extras::currentDesktopChanged, this, [this] (int to) {
         Q_EMIT WorkspaceSwitched(m_currentDesktop, to);
         m_currentDesktop = to;
     });
-    connect(m_windowSystem, &KWindowSystem::numberOfDesktopsChanged, this, &DeepinWMFaker::workspaceCountChanged);
-    connect(_gsettings_dde_appearance, &QGSettings::changed, this, &DeepinWMFaker::onGsettingsDDEAppearanceChanged);
-    connect(_gsettings_dde_zone, &QGSettings::changed, this, &DeepinWMFaker::onGsettingsDDEZoneChanged);
-
-    // 启动后先将所有热区设置同步一遍
-    const QStringList zoneKeyList = {GsettingsZoneRightUp, GsettingsZoneRightDown,
-                                    GsettingsZoneLeftUp, GsettingsZoneLeftDown};
-
-    // 清理旧数据
-    m_kwinCloseWindowGroup->deleteGroup();
-    m_kwinRunCommandGroup->deleteGroup();
-
-    // 设置新数据
-    for (const QString &key : zoneKeyList) {
-        onGsettingsDDEZoneChanged(key);
-    }
+    connect(KX11Extras::self(), &KX11Extras::numberOfDesktopsChanged, this, &DeepinWMFaker::workspaceCountChanged);
+    connect(m_appearance.data(), SIGNAL(valueChanged(const QString &)),this,SLOT(DeepinWMFaker::onGsettingsDDEAppearanceChanged));
 #endif // DISABLE_DEEPIN_WM
 
     QDBusConnection::sessionBus().connect(KWinDBusService, KWinDBusCompositorPath, KWinDBusCompositorInterface,
                                           "compositingToggled", "b", this, SLOT(wmCompositingEnabledChanged(bool)));
+    QDBusConnection::sessionBus().connect(KWinDBusService, KWinDBusPath, KWinDBusInterface, "MultitaskStateChanged", this, SLOT(SlotUpdateMultitaskStatus(bool)));
 
     // 迁移旧的标题栏主题插件配置
     KConfigGroup decoration_group(m_kwinConfig, "org.kde.kdecoration2");
@@ -468,14 +462,14 @@ int DeepinWMFaker::cursorSize() const
 }
 
 #ifndef DISABLE_DEEPIN_WM
-static QString getWorkspaceBackgroundOfDeepinWM(const int index)
+QString DeepinWMFaker::getWorkspaceBackgroundOfDeepinWM(const int index) const
 {
-    return _gsettings_dde_appearance->get(GsettingsBackgroundUri).toStringList().value(index - 1);
+    return m_appearance->value(DconfigBackgroundUri).toStringList().value(index - 1);
 }
 
-static void setWorkspaceBackgroundForDeepinWM(const int index, const QString &uri)
+void DeepinWMFaker::setWorkspaceBackgroundForDeepinWM(const int index, const QString &uri) const
 {
-    QStringList all_wallpaper = _gsettings_dde_appearance->get(GsettingsBackgroundUri).toStringList();
+    QStringList all_wallpaper = m_appearance->value(DconfigBackgroundUri).toStringList();
 
     // 当设置的工作区编号大于列表长度时，先填充数据
     if (index > all_wallpaper.size()) {
@@ -488,7 +482,7 @@ static void setWorkspaceBackgroundForDeepinWM(const int index, const QString &ur
 
     all_wallpaper[index - 1] = uri;
     // 将壁纸设置同步到 deepin-wm
-    _gsettings_dde_appearance->set(GsettingsBackgroundUri, all_wallpaper);
+    m_appearance->setValue(DconfigBackgroundUri, all_wallpaper);
 }
 #endif // DISABLE_DEEPIN_WM
 
@@ -588,7 +582,7 @@ void DeepinWMFaker::SetTransientBackground(const QString &uri)
 
 void DeepinWMFaker::SetTransientBackgroundForMonitor(const QString &uri, const QString &strMonitorName)
 {
-     int current = m_windowSystem->currentDesktop();
+     int current = KX11Extras::currentDesktop();
 
      m_transientBackgroundUri = uri;
      Q_EMIT WorkspaceBackgroundChangedForMonitor( current,strMonitorName,uri );
@@ -887,11 +881,13 @@ void DeepinWMFaker::PreviewWindow(uint xid)
     }
 
     // 使用kwin自带的预览特效
-    if (KWindowEffects::isEffectAvailable(KWindowEffects::HighlightWindows)) {
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.KWin.HighlightWindow")) {
+        //if (KWindowEffects::isEffectAvailable(KWindowEffects::HighlightWindows)) {
         // ###(zccrs): 按道理讲 previewingController 应该为dock的预览展示窗口（发起预览请求的窗口）
         // 不过，dde-dock中不支持此种用法，而且对kwin接口的调用仅仅是fallback，因此直接将xid作为预览请求的controller窗口
-        previewingController = xid;
-        KWindowEffects::highlightWindows(previewingController, {xid});
+        //previewingController = xid;
+        //KWindowEffects::highlightWindows(previewingController, {xid});
+        callHighlightWindows({QString::number(xid)});
         return;
     }
 
@@ -902,7 +898,7 @@ void DeepinWMFaker::PreviewWindow(uint xid)
     // qDebug() << "order" << m_windowSystem->stackingOrder();
     // qDebug() << "contains" << m_windowSystem->hasWId(xid);
 
-    m_windowSystem->forceActiveWindow(xid);
+    KX11Extras::forceActiveWindow(xid);
     m_previewWinMiniPair.first = xid;
     m_previewWinMiniPair.second = false;
 
@@ -926,20 +922,23 @@ void DeepinWMFaker::CancelPreviewWindow()
 
     // 退出kwin自带的预览特效
     if (previewingController) {
-        KWindowEffects::highlightWindows(previewingController, {});
+        //KWindowEffects::highlightWindows(previewingController, {});
+        callHighlightWindows({QString::number(previewingController)});
         previewingController = 0;
         return;
     }
 
     // FIXME: same as above
-    if (m_windowSystem->windows().contains(m_previewWinMiniPair.first)) {
+    if (KX11Extras::windows().contains(m_previewWinMiniPair.first)) {
         if (m_previewWinMiniPair.second) {
-//            m_windowSystem->minimizeWindow(m_previewWinMiniPair.first);
+            // m_windowSystem->minimizeWindow(m_previewWinMiniPair.first);
             // using this way to minimize a window without animation
-            m_windowSystem->setState(m_previewWinMiniPair.first, NET::Hidden);
+            KX11Extras::setState(m_previewWinMiniPair.first, NET::Hidden);
             return;
         }
-        m_windowSystem->lowerWindow(m_previewWinMiniPair.first);
+        // TODO, in kf6, lowerWindow is deprecated and be removed,and the source code lowerWindow implementation is empty
+        // https://github.com/KDE/kwindowsystem/blob/kf5/src/kwindowsystem.cpp
+        //m_windowSystem->lowerWindow(m_previewWinMiniPair.first);
     }
 }
 
@@ -988,7 +987,7 @@ void DeepinWMFaker::ToggleActiveWindowMaximize()
 
 void DeepinWMFaker::MinimizeActiveWindow()
 {
-    m_windowSystem->minimizeWindow(m_windowSystem->activeWindow());
+    KX11Extras::minimizeWindow(KX11Extras::activeWindow());
 }
 
 void DeepinWMFaker::SetDecorationTheme(const QString &type, const QString &name)
@@ -1051,6 +1050,22 @@ bool DeepinWMFaker::maybeShowWarningDialog()
     return false;
 }
 
+void DeepinWMFaker::callHighlightWindows(const QStringList &windowIds)
+{
+    QDBusInterface interface("org.kde.KWin.HighlightWindow", "/org/kde/KWin/HighlightWindow",
+        "org.kde.KWin.HighlightWindow", QDBusConnection::sessionBus());
+    if (interface.isValid()) {
+        QDBusReply<void> reply = interface.call("highlightWindows", QVariant::fromValue(windowIds));
+        if (reply.isValid()) {
+            qDebug() << "Successfully called highlightWindows with" << windowIds;
+        } else {
+            qWarning() << "Failed to call highlightWindows:" << reply.error().message();
+        }
+    } else {
+        qWarning() << "Failed to call highlightWindows:" << interface.lastError().message();
+    }
+}
+
 void DeepinWMFaker::ShowAllWindow()
 {
     if (maybeShowWarningDialog())
@@ -1130,7 +1145,8 @@ void DeepinWMFaker::PresentWindows(const QList<uint> &xids)
         for (uint w : xids)
             windows << w;
 
-        KWindowEffects::presentWindows(windows.first(), windows);
+        // TODO kf6 has no method to present windows
+        //KWindowEffects::presentWindows(windows.first(), windows);
     } else {
         QDBusInterface Interface("org.kde.KWin",
                                  "/org/kde/KWin/PresentWindows",
@@ -1276,7 +1292,7 @@ void DeepinWMFaker::setWorkspaceBackgroundForMonitor(const int index, const QStr
     m_deepinWMConfig->sync();
 
 #ifndef DISABLE_DEEPIN_WM
-    QStringList allWallpaper = _gsettings_dde_appearance->get(GsettingsBackgroundUri).toStringList();
+    QStringList allWallpaper = m_appearance->value(DconfigBackgroundUri).toStringList();
 
     if (index > allWallpaper.size()) {
         allWallpaper.reserve(index);
@@ -1287,7 +1303,7 @@ void DeepinWMFaker::setWorkspaceBackgroundForMonitor(const int index, const QStr
     }
 
     allWallpaper[index - 1] = uri;
-    _gsettings_dde_appearance->set(GsettingsBackgroundUri, allWallpaper);
+    m_appearance->setValue(DconfigBackgroundUri, allWallpaper);
 #endif // DISABLE_DEEPIN_WM
 }
 
@@ -1316,7 +1332,7 @@ void DeepinWMFaker::quitTransientBackground()
 #ifndef DISABLE_DEEPIN_WM
     if (!m_deepinWMBackgroundUri.isEmpty()) {
         // 在退出预览时不同步deepin-wm的设置
-        QSignalBlocker blocker(_gsettings_dde_appearance);
+        QSignalBlocker blocker(m_appearance.data());
         Q_UNUSED(blocker)
         setWorkspaceBackgroundForDeepinWM(GetCurrentWorkspaceInner(), m_deepinWMBackgroundUri);
         m_deepinWMBackgroundUri.clear();
@@ -1327,8 +1343,8 @@ void DeepinWMFaker::quitTransientBackground()
 #ifndef DISABLE_DEEPIN_WM
 void DeepinWMFaker::onGsettingsDDEAppearanceChanged(const QString &key)
 {
-    if (QLatin1String(GsettingsBackgroundUri) == key) {
-        const QStringList &uris = _gsettings_dde_appearance->get(GsettingsBackgroundUri).toStringList();
+    if (QLatin1String(DconfigBackgroundUri) == key) {
+        const QStringList &uris = m_appearance->value(DconfigBackgroundUri).toStringList();
 
         for (int i = 0; i < uris.count(); ++i) {
             const QString &uri = uris.at(i);
@@ -1363,43 +1379,6 @@ static void setBorderActivate(KConfigGroup *group, int value, bool remove)
     group->writeEntry(activate, list.join(","));
 }
 
-void DeepinWMFaker::onGsettingsDDEZoneChanged(const QString &key)
-{
-    ElectricBorder pos = ElectricNone;
-
-    if (key == GsettingsZoneRightUp) {
-        pos = ElectricTopRight;
-    } else if (key == GsettingsZoneRightDown) {
-        pos = ElectricBottomRight;
-    } else if (key == GsettingsZoneLeftDown) {
-        pos = ElectricBottomLeft;
-    } else if (key == GsettingsZoneLeftUp) {
-        pos = ElectricTopLeft;
-    }
-
-    const QString &value = _gsettings_dde_zone->get(key).toString();
-
-    if (value.isEmpty()) {
-        setBorderActivate(m_kwinCloseWindowGroup, pos, true);
-        setBorderActivate(m_kwinRunCommandGroup, pos, true);
-    } else {
-        if (value == "!wm:close") {
-            // 移除这个区域设置的其它命令
-            setBorderActivate(m_kwinRunCommandGroup, pos, true);
-            setBorderActivate(m_kwinCloseWindowGroup, pos, false);
-        } else {
-            // 移除这个区域设置的关闭窗口命令
-            setBorderActivate(m_kwinCloseWindowGroup, pos, true);
-            setBorderActivate(m_kwinRunCommandGroup, pos, false);
-
-            const QString &program = QString("Border%1Program").arg(pos);
-            m_kwinRunCommandGroup->writeEntry(program, value);
-        }
-    }
-
-    syncConfigForKWin();
-}
-
 void DeepinWMFaker::syncConfigForKWin()
 {
     // 同步配置到文件
@@ -1433,6 +1412,11 @@ void DeepinWMFaker::SetMultiTaskingStatus(bool isActive)
     m_isMultitaskingActived = isActive;
 }
 
+void DeepinWMFaker::SlotUpdateMultitaskStatus(bool isActive)
+{
+    m_isMultitaskingActived = isActive;
+}
+
 bool DeepinWMFaker::GetIsShowDesktop()
 {
     return m_isShowDesktop;
