@@ -6,6 +6,7 @@
 #include "appearanceproperty.h"
 #include "impl/appearancemanager.h"
 #include "modules/common/commondefine.h"
+#include "modules/dconfig/dconfigsettings.h"
 
 #include <QMutexLocker>
 
@@ -21,6 +22,7 @@ Appearance1Thread::Appearance1Thread()
     , thread(new QThread(this))
 {
     // 属性初始化
+    DTK_CORE_NAMESPACE::DConfig::setAppId(APPEARANCEAPPID);
     DTK_CORE_NAMESPACE::DConfig settingDconfig(APPEARANCESCHEMA);
     property->globalTheme.init(settingDconfig.value(GSKEYGLOBALTHEME).toString());
     property->gtkTheme.init(settingDconfig.value(GSKEYGTKTHEME).toString());
@@ -33,17 +35,13 @@ Appearance1Thread::Appearance1Thread()
     property->opacity.init(settingDconfig.value(GSKEYOPACITY).toDouble());
     property->wallpaperSlideShow.init(settingDconfig.value(GSKEYWALLPAPERSLIDESHOW).toString());
     property->wallpaperURls.init(settingDconfig.value(GSKEYWALLPAPERURIS).toString());
-    if (QGSettings::isSchemaInstalled(XSETTINGSSCHEMA)) {
-        QGSettings xSetting(XSETTINGSSCHEMA);
-        property->windowRadius.init(xSetting.get(GSKEYDTKWINDOWRADIUS).toInt());
-        QString activeColor = settingDconfig.value(GSKEYGLOBALTHEME).toString().endsWith("dark") ?
-            xSetting.get(GSKEYQTACTIVECOLOR_DARK).toString() : xSetting.get(GSKEYQTACTIVECOLOR).toString();
-        property->qtActiveColor.init(AppearanceManager::qtActiveColorToHexColor(activeColor));
-    }
-    if (QGSettings::isSchemaInstalled(WRAPBGSCHEMA)) {
-        QGSettings wrapBgSetting(WRAPBGSCHEMA);
-        property->background.init(wrapBgSetting.get(GSKEYBACKGROUND).toString());
-    }
+    QString qtActivecolor =  DconfigSettings::ConfigValue(DDEDAEMONAPPID,XSETTINGSNAME,GSKEYQTACTIVECOLOR,"").toString();
+    QString qtDarkActivecolor =  DconfigSettings::ConfigValue(DDEDAEMONAPPID,XSETTINGSNAME,GSKEYQTACTIVECOLOR_DARK,"").toString();
+    int radius = DconfigSettings::ConfigValue(DDEDAEMONAPPID,XSETTINGSNAME,DCKEYDTKWINDOWRADIUS,"").toInt();
+    property->windowRadius.init(radius);
+    QString activeColor = settingDconfig.value(GSKEYGLOBALTHEME).toString().endsWith("dark") ? qtDarkActivecolor : qtActivecolor;
+    property->qtActiveColor.init(AppearanceManager::qtActiveColorToHexColor(activeColor));
+    property->background.init("file:////usr/share/backgrounds/default_background.jpg");
     init();
     // 线程
     moveToThread(thread);
@@ -153,6 +151,17 @@ void Appearance1Thread::setDTKSizeMode(int value)
     appearanceManager->doSetDTKSizeMode(value);
 }
 
+int Appearance1Thread::qtScrollBarPolicy() const
+{
+    return property->qtScrollBarPolicy;
+}
+
+void Appearance1Thread::setQtScrollBarPolicy(int value)
+{
+    QMutexLocker locker(&mutex);
+    appearanceManager->doSetQtScrollBarPolicy(value);
+}
+
 int Appearance1Thread::windowRadius() const
 {
     return property->windowRadius;
@@ -173,51 +182,51 @@ void Appearance1Thread::Delete(const QString &ty, const QString &name, const QDB
 
 QString Appearance1Thread::GetCurrentWorkspaceBackground(const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(appearanceManager->doGetCurrentWorkspaceBackground()));
-    return QString();
+    return appearanceManager->doGetCurrentWorkspaceBackground();
 }
 
 QString Appearance1Thread::GetCurrentWorkspaceBackgroundForMonitor(const QString &strMonitorName, const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(appearanceManager->doGetCurrentWorkspaceBackgroundForMonitor(strMonitorName)));
-    return QString();
+    return appearanceManager->doGetCurrentWorkspaceBackgroundForMonitor(strMonitorName);
 }
 
 double Appearance1Thread::GetScaleFactor(const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(appearanceManager->getScaleFactor()));
-    return 0.0;
+    return appearanceManager->getScaleFactor();
 }
 
 ScaleFactors Appearance1Thread::GetScreenScaleFactors(const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(QVariant::fromValue(appearanceManager->getScreenScaleFactors())));
-    return ScaleFactors();
+    return appearanceManager->getScreenScaleFactors();
 }
 
 QString Appearance1Thread::GetActiveColors(const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(QVariant::fromValue(appearanceManager->getActiveColors())));
-    return QString();
+    return appearanceManager->getActiveColors();
 }
 
 QString Appearance1Thread::GetWallpaperSlideShow(const QString &monitorName, const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(appearanceManager->doGetWallpaperSlideShow(monitorName)));
-    return QString();
+    return appearanceManager->doGetWallpaperSlideShow(monitorName);
 }
 
 QString Appearance1Thread::GetWorkspaceBackgroundForMonitor(const int &index, const QString &strMonitorName, const QDBusMessage &message)
 {
+    Q_UNUSED(message);
     QMutexLocker locker(&mutex);
-    APPEARANCEDBUS.send(message.createReply(appearanceManager->doGetWorkspaceBackgroundForMonitor(index, strMonitorName)));
-    return QString();
+    return appearanceManager->doGetWorkspaceBackgroundForMonitor(index, strMonitorName);
 }
 
 QString Appearance1Thread::List(const QString &ty, const QDBusMessage &message)
@@ -264,10 +273,6 @@ void Appearance1Thread::SetMonitorBackground(const QString &monitorName, const Q
     Q_UNUSED(message);
     QMutexLocker locker(&mutex);
     QString file = appearanceManager->doSetMonitorBackground(monitorName, imageGile);
-
-    if (!file.isEmpty()) {
-        appearanceManager->doSetWsLoop(monitorName, file);
-    }
 }
 
 void Appearance1Thread::SetScaleFactor(double scale, const QDBusMessage &message)
