@@ -14,21 +14,21 @@
 #include "modules/common/commondefine.h"
 #include "modules/dconfig/phasewallpaper.h"
 #include "modules/subthemes/customtheme.h"
+#include "modules/dconfig/dconfigsettings.h"
 
-#include <dguiapplicationhelper.h>
-#include <xcb/randr.h>
 #include <xcb/xcb.h>
+#include <KX11Extras>
 
 #include <QColor>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QRegExp>
 #include <QSettings>
-#include <QTimeZone>
 #include <QTimer>
 #include <QMetaObject>
 #include <QCoreApplication>
+#include <DDBusSender>
+#include <QRandomGenerator>
 
 #include <pwd.h>
 
@@ -36,7 +36,6 @@
 #define DEFAULT_WORKSPACE_COUNT (2) // 默认工作区数量
 
 DCORE_USE_NAMESPACE
-DGUI_USE_NAMESPACE
 
 AppearanceManager::AppearanceManager(AppearanceProperty *prop, QObject *parent)
     : QObject(parent)
@@ -56,20 +55,15 @@ AppearanceManager::AppearanceManager(AppearanceProperty *prop, QObject *parent)
     , m_customTheme(new CustomTheme())
     , m_globalThemeUpdating(false)
     , m_wallpaperConfig({})
-    , m_opacityTriggerTimer(new QTimer(this))
+    , m_setDefaulting(false)
 {
-    if (QGSettings::isSchemaInstalled(XSETTINGSSCHEMA)) {
-        m_xSetting = QSharedPointer<QGSettings>(new QGSettings(XSETTINGSSCHEMA));
-    }
-
-    if (QGSettings::isSchemaInstalled(WRAPBGSCHEMA)) {
-        m_wrapBgSetting = QSharedPointer<QGSettings>(new QGSettings(WRAPBGSCHEMA));
-    }
-
-    if (QGSettings::isSchemaInstalled(XSETTINGSSCHEMA)) {
-        m_gnomeBgSetting = QSharedPointer<QGSettings>(new QGSettings(GNOMEBGSCHEMA));
+    m_XSettingsDconfig = QSharedPointer<DConfig>(DconfigSettings::ConfigPtr(DDEDAEMONAPPID,XSETTINGSNAME));
+    if (!m_XSettingsDconfig) {
+        qWarning() << "XSettingsDconfig is NULL";
+        exit(-1);
     }
 
+    m_fontsManager->xSetting = m_XSettingsDconfig;
     init();
 }
 
@@ -83,6 +77,7 @@ bool AppearanceManager::init()
 {
     qInfo() << "init";
     getScaleFactor();
+    initGlobalOverrideConfig();
     // subthemes需要在获取ScaleFactor后再初始化
     m_subthemes.reset(new Subthemes(this));
 
@@ -90,17 +85,6 @@ bool AppearanceManager::init()
     initUserObj();
     initCurrentBgs();
 
-    xcb_connection_t *conn = xcb_connect(nullptr, nullptr);
-    xcb_randr_query_version_reply_t *v = xcb_randr_query_version_reply(conn, xcb_randr_query_version(conn, 1, 1), nullptr);
-    if (v == nullptr) {
-        qWarning() << "xcb_randr_query_version_reply faile";
-        return false;
-    }
-    m_opacityTriggerTimer->setSingleShot(true);
-    m_opacityTriggerTimer->setInterval(200);
-
-    connect(m_opacityTriggerTimer, &QTimer::timeout, this, &AppearanceManager::onOpacityTriggerTimeout);
-
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::workspaceCountChanged, this, &AppearanceManager::handleWmWorkspaceCountChanged);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::SetScaleFactorStarted, this, &AppearanceManager::handleSetScaleFactorStarted);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::SetScaleFactorDone, this, &AppearanceManager::handleSetScaleFactorDone);
@@ -112,20 +96,11 @@ bool AppearanceManager::init()
 
     new ThemeFontSyncConfig("org.deepin.dde.Appearance1", "/org/deepin/dde/Appearance1/sync", QSharedPointer<AppearanceManager>(this));
     new BackgroundSyncConfig("org.deepin.dde.Appearance1", "/org/deepin/dde/Appearance1/Background", QSharedPointer<AppearanceManager>(this));
-
-    if (m_property->wallpaperURls->isEmpty()) {
-        updateNewVersionData();
-    }
-    initWallpaperSlideshow();
     m_zone = m_dbusProxy->timezone();
 
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::TimezoneChanged, this, &AppearanceManager::handleTimezoneChanged);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::NTPChanged, this, &AppearanceManager::handleTimeUpdate);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::TimeUpdate, this, &AppearanceManager::handleTimeUpdate);
-    connect(m_dbusProxy.get(), &AppearanceDBusProxy::HandleForSleep, this, &AppearanceManager::handlePrepareForSleep);
-
-    initDtkSizeMode();
-    initGlobalTheme();
 
     QVector<QSharedPointer<Theme>> iconList = m_subthemes->listIconThemes();
     bool bFound = false;
@@ -154,16 +129,16 @@ bool AppearanceManager::init()
         doSetCursorTheme(DEFAULTCURSORTHEME);
     }
 
+    initDtkSizeMode();
+    initGlobalTheme();
+
     connect(m_fsnotify.data(), SIGNAL(themeFileChange(QString)), this, SLOT(handlethemeFileChange(QString)), Qt::QueuedConnection);
 
-    connect(m_xSetting.data(), SIGNAL(changed(const QString &)), this, SLOT(handleXsettingDConfigChange(QString)));
+    // connect(m_xSetting.data(), SIGNAL(changed(const QString &)), this, SLOT(handleXsettingDConfigChange(QString)));
 
     connect(&m_settingDconfig, SIGNAL(valueChanged(const QString &)), this, SLOT(handleSettingDConfigChange(QString)));
 
-    connect(m_wrapBgSetting.data(), SIGNAL(changed(const QString)), this, SLOT(handleWrapBgDConfigChange(QString)));
-
-    connect(m_gnomeBgSetting.data(), SIGNAL(changed(const QString)), this, SLOT(handleGnomeBgDConfigChange(QString)));
-
+    connect(m_XSettingsDconfig.data(),SIGNAL(valueChanged(const QString &)),this,SLOT(handleXsettingDConfigChange(QString)));
     connect(&m_detectSysClockTimer, SIGNAL(timeout()), this, SLOT(handleDetectSysClockTimeOut()));
     connect(&m_themeAutoTimer, SIGNAL(timeout()), this, SLOT(handleGlobalThemeChangeTimeOut()));
     m_themeAutoTimer.start(60000); // 每分钟检查一次是否要切换主题
@@ -275,9 +250,6 @@ void AppearanceManager::handlethemeFileChange(QString theme)
         Q_EMIT Refreshed(TYPEGLOBALTHEME);
     } else if (theme == TYPEBACKGROUND) {
         m_backgrounds->notifyChanged();
-        for (auto iter : m_wsLoopMap) {
-            iter->notifyFileChange();
-        }
     } else if (theme == TYPEGTK) {
         // todo <-time.After(time.Millisecond * 700)
         m_subthemes->refreshGtkThemes();
@@ -293,15 +265,15 @@ void AppearanceManager::handlethemeFileChange(QString theme)
 
 void AppearanceManager::handleXsettingDConfigChange(QString key)
 {
-    if (key == GSKEYQTACTIVECOLOR || key == GSKEYQTACTIVECOLOR_DARK) {
+    if (key == DCKEYQTDARKACTIVECOLOR || key == DCKEYQTACTIVECOLOR) {
         QString result = m_settingDconfig.value(GSKEYGLOBALTHEME).toString().endsWith("dark") ?
-            m_xSetting->get(GSKEYQTACTIVECOLOR_DARK).toString() : m_xSetting->get(GSKEYQTACTIVECOLOR).toString();
+            m_XSettingsDconfig->value(DCKEYQTDARKACTIVECOLOR).toString() : m_XSettingsDconfig->value(DCKEYQTACTIVECOLOR).toString();
         QString value = qtActiveColorToHexColor(result);
 
         m_property->qtActiveColor = value;
         Q_EMIT Changed("QtActiveColor", value);
-    } else if (key == GSKEYDTKWINDOWRADIUS) {
-        m_property->windowRadius = m_xSetting->get(GSKEYDTKWINDOWRADIUS).toInt();
+    } else if (key == DCKEYDTKWINDOWRADIUS) {
+        m_property->windowRadius = m_XSettingsDconfig->value(DCKEYDTKWINDOWRADIUS).toInt();
         Q_EMIT Changed("WindowRadius", QString::number(m_property->windowRadius));
     }
 }
@@ -380,7 +352,7 @@ void AppearanceManager::handleSettingDConfigChange(QString key)
         } else if (key == GSKEYWALLPAPERSLIDESHOW) {
             type = TYPEWALLPAPERSLIDESHOW;
             value = m_settingDconfig.value(key).toString();
-            updateWSPolicy(value);
+            // noting to do, move to deepin-service-manager
         } else if (key == GSKEYOPACITY) {
             type = TYPEWINDOWOPACITY;
             bool ok = false;
@@ -406,7 +378,16 @@ void AppearanceManager::handleSettingDConfigChange(QString key)
             if (ok) {
                 doSetDTKSizeMode(mode);
             }
-        } else {
+        } else if (key == DQTSCROLLBARPOLICY) {
+            type = TYPEQTSCROLLBARPOLICY;
+            bool ok = false;
+            int policy = m_settingDconfig.value(key).toInt(&ok);
+            if (ok) {
+                setQtScrollBarPolicy(policy);
+                value = QString::number(policy);
+            }
+        }
+        else {
             return;
         }
     } while (false);
@@ -420,40 +401,6 @@ void AppearanceManager::handleSettingDConfigChange(QString key)
     }
 }
 
-void AppearanceManager::handleWrapBgDConfigChange(QString key)
-{
-    if (key != GSKEYBACKGROUND) {
-        return;
-    }
-
-    QString value = m_wrapBgSetting->get(key).toString();
-    bool bSuccess = doSetBackground(value);
-    if (!bSuccess) {
-        return;
-    }
-
-    if (m_wsLoopMap.count(m_curMonitorSpace) != 0) {
-        m_wsLoopMap[m_curMonitorSpace]->addToShow(value);
-    }
-}
-
-void AppearanceManager::handleGnomeBgDConfigChange(QString key)
-{
-    if (key != GSKEYBACKGROUND) {
-        return;
-    }
-
-    QString value = m_gnomeBgSetting->get(key).toString();
-    bool bSuccess = doSetBackground(value);
-    if (!bSuccess) {
-        return;
-    }
-
-    if (m_wsLoopMap.count(m_curMonitorSpace) != 0) {
-        m_wsLoopMap[m_curMonitorSpace]->addToShow(value);
-    }
-}
-
 void AppearanceManager::handleDetectSysClockTimeOut()
 {
 
@@ -579,6 +526,14 @@ void AppearanceManager::setDTKSizeMode(int value)
     }
 }
 
+void AppearanceManager::setQtScrollBarPolicy(int value)
+{
+    if (value != m_property->qtScrollBarPolicy && m_settingDconfig.isValid()) {
+        m_settingDconfig.setValue(DQTSCROLLBARPOLICY, value);
+        m_property->qtScrollBarPolicy = value;
+    }
+}
+
 void AppearanceManager::setActiveColors(const QString &value)
 {
     m_settingDconfig.setValue(DACTIVECOLORS, value);
@@ -586,14 +541,14 @@ void AppearanceManager::setActiveColors(const QString &value)
     if (colors.isEmpty()) {
         return;
     }
-    m_xSetting->set(GSKEYQTACTIVECOLOR, hexColorToQtActiveColor(colors.value(0)));
-    m_xSetting->set(GSKEYQTACTIVECOLOR_DARK, hexColorToQtActiveColor(colors.value(1)));
+    m_XSettingsDconfig->setValue(DCKEYQTACTIVECOLOR, hexColorToQtActiveColor(colors.value(0)));
+    m_XSettingsDconfig->setValue(DCKEYQTDARKACTIVECOLOR, hexColorToQtActiveColor(colors.value(1)));
 }
 
 void AppearanceManager::setWindowRadius(int value)
 {
-    if (value != m_property->windowRadius && m_xSetting) {
-        m_xSetting->set(GSKEYDTKWINDOWRADIUS, value);
+    if (value != m_property->windowRadius && m_XSettingsDconfig) {
+        m_XSettingsDconfig->setValue(DCKEYDTKWINDOWRADIUS, value);
         m_property->windowRadius = value;
         updateCustomTheme(TYPWINDOWRADIUS, QString::number(value));
     }
@@ -601,18 +556,10 @@ void AppearanceManager::setWindowRadius(int value)
 
 void AppearanceManager::setOpacity(double value)
 {
-    m_tmpOpacity = value;
-    if (!m_opacityTriggerTimer->isActive()) {
-        m_opacityTriggerTimer->start();
-    }
-}
-
-void AppearanceManager::onOpacityTriggerTimeout()
-{
-    if (m_settingDconfig.isValid() && !qFuzzyCompare(m_tmpOpacity, m_property->opacity)) {
-        m_settingDconfig.setValue(GSKEYOPACITY, m_tmpOpacity);
-        m_property->opacity = m_tmpOpacity;
-        updateCustomTheme(TYPEWINDOWOPACITY, QString::number(m_tmpOpacity));
+    if (m_settingDconfig.isValid() && !qFuzzyCompare(value, m_property->opacity)) {
+        m_settingDconfig.setValue(GSKEYOPACITY, value);
+        m_property->opacity = value;
+        updateCustomTheme(TYPEWINDOWOPACITY, QString::number(value));
     }
 }
 
@@ -622,7 +569,7 @@ void AppearanceManager::setQtActiveColor(const QString &value)
     QString activeColors = m_settingDconfig.value(DACTIVECOLORS).toString();
     QStringList colors = activeColors.split(',');
     QString result = m_currentGlobalTheme.endsWith("dark") ? colors.value(1) : colors.value(0);
-    if (QColor(result) != QColor(m_property->qtActiveColor) && m_xSetting) {
+    if (result != m_property->qtActiveColor && m_XSettingsDconfig) {
         m_property->qtActiveColor = result;
         updateCustomTheme(TYPEACTIVECOLOR, activeColors);
     }
@@ -750,49 +697,6 @@ void AppearanceManager::initCurrentBgs()
     m_greeterBg = m_dbusProxy->greeterBackground();
 }
 
-void AppearanceManager::initWallpaperSlideshow()
-{
-    loadWSConfig();
-
-    QJsonParseError err;
-    QJsonDocument doc = QJsonDocument::fromJson(m_property->wallpaperSlideShow->toLatin1(), &err);
-    if (err.error != QJsonParseError::NoError) {
-        qWarning() << "parse wallpaperSlideShow: " << m_property->wallpaperSlideShow << ",fail";
-        return;
-    }
-
-    QVariantMap tempMap = doc.object().toVariantMap();
-    for (auto iter : tempMap.toStdMap()) {
-        if (m_wsSchedulerMap.count(iter.first) != 1) {
-            QSharedPointer<WallpaperScheduler> wallpaperScheduler(
-                    new WallpaperScheduler(std::bind(&AppearanceManager::autoChangeBg, this, std::placeholders::_1, std::placeholders::_2)));
-            m_wsSchedulerMap[iter.first] = wallpaperScheduler;
-        }
-
-        if (!m_wsLoopMap.contains(iter.first)) {
-            m_wsLoopMap[iter.first] = QSharedPointer<WallpaperLoop>(new WallpaperLoop());
-        }
-
-        if (WallpaperLoopConfigManger::isValidWSPolicy(iter.second.toString())) {
-            if (iter.second.toString() == WSPOLICYLOGIN) {
-                bool bSuccess = changeBgAfterLogin(iter.first);
-                if (!bSuccess) {
-                    qWarning() << "failed to change background after login";
-                }
-            } else {
-                bool ok;
-                uint sec = iter.second.toString().toUInt(&ok);
-                if (m_wsSchedulerMap.count(iter.first) == 1) {
-                    if (ok) {
-                        m_wsSchedulerMap[iter.first]->setInterval(iter.first, sec);
-                    } else {
-                        m_wsSchedulerMap[iter.first]->stop();
-                    }
-                }
-            }
-        }
-    }
-}
 
 void AppearanceManager::updateMonitorMap()
 {
@@ -807,30 +711,16 @@ void AppearanceManager::updateMonitorMap()
     }
 }
 
-void AppearanceManager::handlePrepareForSleep(bool sleep)
-{
-    if (sleep)
-        return;
-
-    QJsonDocument doc = QJsonDocument::fromJson(m_property->wallpaperSlideShow->toLatin1());
-    QVariantMap tempMap = doc.object().toVariantMap();
-
-    for (auto it = tempMap.begin(); it != tempMap.end(); ++it) {
-        if (it.value().toString() == WSPOLICYWAKEUP)
-            autoChangeBg(it.key(), QDateTime::currentDateTimeUtc());
-    }
-}
-
 void AppearanceManager::iso6709Parsing(QString city, QString coordinates)
 {
-    QRegExp pattern("(\\+|-)\\d+\\.?\\d*");
+    QRegularExpression pattern(R"((\+|-)\d+\.?\d*)");
 
     QVector<QString> resultVet;
 
-    int pos = 0;
-    while ((pos = pattern.indexIn(coordinates, pos)) != -1 && resultVet.size() <= 2) {
-        resultVet.push_back(coordinates.mid(pos, pattern.matchedLength()));
-        pos += pattern.matchedLength();
+    QRegularExpressionMatchIterator it = pattern.globalMatch(coordinates);
+    while (it.hasNext() && resultVet.size() <= 2) {
+        QRegularExpressionMatch match = it.next();
+        resultVet.push_back(match.captured(0));
     }
 
     if (resultVet.size() < 2) {
@@ -882,11 +772,6 @@ void AppearanceManager::doUpdateWallpaperURIs()
     if (monitorWallpaperUris.isEmpty()) {
         return;
     }
-
-    // 如果是用户自己设置的桌面壁纸, 需要将主题更新为自定义
-    if (!monitorWallpaperUris.first().startsWith("/usr/share/wallpapers/deepin")) {
-        updateCustomTheme(TYPEWALLPAPER, monitorWallpaperUris.first());
-    }
 }
 
 void AppearanceManager::setPropertyWallpaperURIs(QMap<QString, QString> monitorWallpaperUris)
@@ -1005,71 +890,6 @@ void AppearanceManager::enableDetectSysClock(bool enable)
     }
 }
 
-void AppearanceManager::updateWSPolicy(QString policy)
-{
-    QJsonParseError error;
-    QJsonDocument doc = QJsonDocument::fromJson(policy.toLatin1(), &error);
-    if (error.error != QJsonParseError::NoError) {
-        qWarning() << "json error:" << policy << error.errorString();
-        return;
-    }
-    loadWSConfig();
-
-    QVariantMap config = doc.object().toVariantMap();
-    for (auto iter : config.toStdMap()) {
-        if (m_wsSchedulerMap.count(iter.first) == 0) {
-            QSharedPointer<WallpaperScheduler> wallpaperScheduler(
-                    new WallpaperScheduler(std::bind(&AppearanceManager::autoChangeBg, this, std::placeholders::_1, std::placeholders::_2)));
-            m_wsSchedulerMap[iter.first] = wallpaperScheduler;
-        }
-
-        if (m_wsLoopMap.count(iter.first) == 0) {
-            m_wsLoopMap[iter.first] = QSharedPointer<WallpaperLoop>(new WallpaperLoop());
-        }
-
-        if (m_curMonitorSpace == iter.first && WallpaperLoopConfigManger::isValidWSPolicy(iter.second.toString())) {
-            bool bOk;
-            int nSec = iter.second.toString().toInt(&bOk);
-            if (bOk) {
-                QDateTime curr = QDateTime::currentDateTimeUtc();
-                QMetaObject::invokeMethod(qApp, [this, iter, curr](){ 
-                       m_wsSchedulerMap[iter.first]->setLastChangeTime(curr);
-                    }, Qt::QueuedConnection);
-                QMetaObject::invokeMethod(qApp, [this, iter, nSec](){ 
-                       m_wsSchedulerMap[iter.first]->setInterval(iter.first, nSec);
-                    }, Qt::QueuedConnection);
-                saveWSConfig(iter.first, curr);
-            } else {
-                m_wsSchedulerMap[iter.first]->stop();
-            }
-        }
-    }
-}
-
-void AppearanceManager::loadWSConfig()
-{
-    WallpaperLoopConfigManger wallConfig;
-    QString fileName = utils::GetUserConfigDir() + "/deepin/dde-daemon/appearance/wallpaper-slideshow.json";
-    WallpaperLoopConfigManger::WallpaperLoopConfigMap cfg = wallConfig.loadWSConfig(fileName);
-
-    for (auto monitorSpace : cfg.keys()) {
-        if (m_wsSchedulerMap.count(monitorSpace) == 0) {
-            QSharedPointer<WallpaperScheduler> wallpaperScheduler(
-                    new WallpaperScheduler(std::bind(&AppearanceManager::autoChangeBg, this, std::placeholders::_1, std::placeholders::_2)));
-            m_wsSchedulerMap[monitorSpace] = wallpaperScheduler;
-        }
-
-        m_wsSchedulerMap[monitorSpace]->setLastChangeTime(cfg[monitorSpace].lastChange);
-
-        if (m_wsLoopMap.count(monitorSpace) == 0) {
-            m_wsLoopMap[monitorSpace] = QSharedPointer<WallpaperLoop>(new WallpaperLoop());
-        }
-
-        for (auto file : cfg[monitorSpace].showedList) {
-            m_wsLoopMap[monitorSpace]->addToShow(file);
-        }
-    }
-}
 
 QDateTime AppearanceManager::getThemeAutoChangeTime(QDateTime date, double latitude, double longitude)
 {
@@ -1184,12 +1004,12 @@ bool AppearanceManager::doSetGlobalTheme(QString value)
     m_currentGlobalTheme = value;
     switch (mode) {
     case Light:
-        applyGlobalTheme(theme, defaultTheme, defaultTheme, themePath);
+        applyGlobalTheme(theme, defaultTheme, defaultTheme, themePath, themeId);
         break;
     case Dark: {
         if (darkTheme.isEmpty())
             return false;
-        applyGlobalTheme(theme, darkTheme, defaultTheme, themePath);
+        applyGlobalTheme(theme, darkTheme, defaultTheme, themePath, themeId);
     } break;
     case Auto: {
         setGlobalTheme(value);
@@ -1300,6 +1120,10 @@ bool AppearanceManager::doSetMonospaceFont(QString value)
 
 bool AppearanceManager::doSetBackground(QString value)
 {
+    if (checkWallpaperLockedStatus()) {
+        return false;
+    }
+
     if (!m_backgrounds->isBackgroundFile(value)) {
         return false;
     }
@@ -1318,6 +1142,9 @@ bool AppearanceManager::doSetBackground(QString value)
 
 bool AppearanceManager::doSetGreeterBackground(QString value)
 {
+    if (checkWallpaperLockedStatus()) {
+        return false;
+    }
     value = utils::enCodeURI(value, SCHEME_FILE);
     m_greeterBg = value;
     m_dbusProxy->SetGreeterBackground(value);
@@ -1342,8 +1169,16 @@ QString AppearanceManager::doGetWallpaperSlideShow(QString monitorName)
 
 double AppearanceManager::getScaleFactor()
 {
-    double scaleFactor = m_dbusProxy->GetScaleFactor();
+    double scaleFactor = 0.0;
+    if (m_XSettingsDconfig) {
+        scaleFactor = m_XSettingsDconfig->value("scale-factor").toDouble();
+    } else {
+        scaleFactor = m_dbusProxy->GetScaleFactor();
+    }
     qInfo() << __FUNCTION__ << "UpdateScaleFactor" << scaleFactor;
+    if (scaleFactor <= 0) {
+        scaleFactor = 1.0;
+    }
     UpdateScaleFactor(scaleFactor);
     return scaleFactor;
 }
@@ -1386,8 +1221,10 @@ QString AppearanceManager::doList(QString type)
     } else if (type == TYPEBACKGROUND) {
         return marshal(backgroundListVerify(m_backgrounds->listBackground()));
     } else if (type == TYPESTANDARDFONT) {
+        m_fontsManager->refreshFamilyList();
         return marshal(m_fontsManager->listStandard());
     } else if (type == TYPEMONOSPACEFONT) {
+        m_fontsManager->refreshFamilyList();
         return marshal(m_fontsManager->listMonospace());
     } else if (type == TYPEGLOBALTHEME) {
         return marshal(m_subthemes->listGlobalThemes());
@@ -1492,7 +1329,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
 {
     bool updateValut = false;
     if (type == TYPEGTK) {
-        if (value == m_property->gtkTheme) {
+        if (!m_setDefaulting && value == m_property->gtkTheme) {
             return;
         }
 
@@ -1501,7 +1338,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
             updateValut = true;
         }
     } else if (type == TYPEICON) {
-        if (value == m_property->iconTheme) {
+        if (!m_setDefaulting && value == m_property->iconTheme) {
             return;
         }
 
@@ -1510,7 +1347,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
             updateValut = true;
         }
     } else if (type == TYPECURSOR) {
-        if (value == m_property->cursorTheme) {
+        if (!m_setDefaulting && value == m_property->cursorTheme) {
             return;
         }
 
@@ -1519,7 +1356,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
             updateValut = true;
         }
     } else if (type == TYPEGLOBALTHEME) {
-        if (value == m_property->globalTheme) {
+        if (!m_setDefaulting && value == m_property->globalTheme) {
             return;
         }
         if (doSetGlobalTheme(value)) {
@@ -1527,14 +1364,13 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
         }
     } else if (type == TYPEBACKGROUND) {
         bool bSuccess = doSetBackground(value);
-        if (bSuccess && m_wsLoopMap.count(m_curMonitorSpace) == 1) {
-            m_wsLoopMap[m_curMonitorSpace]->addToShow(value);
+        if (bSuccess) {
             updateValut = true;
         }
     } else if (type == TYPEGREETERBACKGROUND) {
-        updateValut = doSetGreeterBackground(value);
+        doSetGreeterBackground(value);
     } else if (type == TYPESTANDARDFONT) {
-        if (m_property->standardFont == value) {
+        if (!m_setDefaulting &&m_property->standardFont == value) {
             return;
         }
         if (doSetStandardFont(value)) {
@@ -1542,7 +1378,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
             updateValut = true;
         }
     } else if (type == TYPEMONOSPACEFONT) {
-        if (m_property->monospaceFont == value) {
+        if (!m_setDefaulting && m_property->monospaceFont == value) {
             return;
         }
         if (doSetMonospaceFont(value)) {
@@ -1551,7 +1387,7 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
         }
     } else if (type == TYPEFONTSIZE) {
         double size = value.toDouble();
-        if (m_property->fontSize > size - 0.01 && m_property->fontSize < size + 0.01) {
+        if (!m_setDefaulting && m_property->fontSize > size - 0.01 && m_property->fontSize < size + 0.01) {
             return;
         }
         setFontSize(size);
@@ -1571,7 +1407,6 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
         }
     } else if (type == TYPEWALLPAPER) {
         doSetCurrentWorkspaceBackground(value);
-        updateValut = true;
     } else if (type == TYPEDTKSIZEMODE) {
         bool ok = false;
         int mode = value.toInt(&ok);
@@ -1579,6 +1414,12 @@ void AppearanceManager::doSetByType(const QString &type, const QString &value)
             QString fontSizeKey = GSKEYFONTSIZE;
             doSetDTKSizeMode(mode);
         }
+    } else if (type == TYPEQTSCROLLBARPOLICY) {
+        bool ok = false;
+        int policy = value.toInt(&ok);
+        if (ok) {
+            doSetQtScrollBarPolicy(policy);
+        }
     }
 
     if (updateValut) {
@@ -1640,42 +1481,42 @@ bool AppearanceManager::doSetWallpaperSlideShow(const QString &monitorName, cons
     return true;
 }
 
-bool AppearanceManager::doSetWsLoop(const QString &monitorName, const QString &file)
-{
-    int index = m_dbusProxy->GetCurrentWorkspace();
-    QString monitor = QString("%1&&%2").arg(monitorName).arg(index);
-    if (m_wsLoopMap.count(monitor) == 1) {
-        m_wsLoopMap[monitor]->addToShow(file);
-    }
-
-    return true;
-}
-
 int AppearanceManager::getCurrentDesktopIndex()
 {
-    return m_dbusProxy->GetCurrentWorkspace();
+    if (utils::isTreeland()) {
+        // TODO: Need to implement
+        return 0;
+    } else {
+        return KX11Extras::currentDesktop();
+    }
 }
 
-void AppearanceManager::applyGlobalTheme(KeyFile &theme, const QString &themeName, const QString &defaultTheme, const QString &themePath)
+void AppearanceManager::applyGlobalTheme(KeyFile &theme, const QString &themeName, const QString &defaultTheme, const QString &themePath, const QString &themeId)
 {
     m_globalThemeUpdating = true;
     QString defTheme = (defaultTheme.isEmpty() || defaultTheme == themeName) ? QString() : defaultTheme;
+    auto getValue = [&theme, &themeId, this](const QString &section, const QString &key) -> QString{
+        QString ret = theme.getStr(section, key);
+        for (auto &overrideItem : this->m_globalThemeOverrideMap.value(themeId)) {
+            if (overrideItem.section == section && overrideItem.key == key) {
+                ret = overrideItem.value;
+                break;
+            }
+        }
+        return ret;
+    };
     // 设置globlaTheme的一项，先从themeName中找对应项，若没有则从defTheme中找对应项，最后调用doSetByType实现功能
-    auto setGlobalItem = [&theme, &themeName, &defTheme, this](const QString &key, const QString &type) {
-        QString themeValue = theme.getStr(themeName, key);
+    auto setGlobalItem = [&theme, &themeName, &defTheme, getValue, this](const QString &key, const QString &type) {
+        QString themeValue = getValue(themeName, key);
         if (themeValue.isEmpty() && !defTheme.isEmpty())
-            themeValue = theme.getStr(defTheme, key);
+            themeValue = getValue(defTheme, key);
         if (!themeValue.isEmpty())
             doSetByType(type, themeValue);
     };
-    auto setGlobalFile = [&theme, &themeName, &defTheme, &themePath, this](const QString &key, const QString &type) {
-        QString themeValue = theme.getStr(themeName, key);
-        // 如果是用户自定义的桌面壁纸, 切换主题的外观时, 不重新设置壁纸
-        if (isSkipSetWallpaper(themePath) && type == TYPEWALLPAPER) {
-            return;
-        }
+    auto setGlobalFile = [&theme, &themeName, &defTheme, getValue, &themePath, this](const QString &key, const QString &type) {
+        QString themeValue = getValue(themeName, key);
         if (themeValue.isEmpty() && !defTheme.isEmpty())
-            themeValue = theme.getStr(defTheme, key);
+            themeValue = getValue(defTheme, key);
         if (!themeValue.isEmpty()) {
             themeValue = utils::deCodeURI(themeValue);
             QFileInfo fileInfo(themeValue);
@@ -1686,15 +1527,9 @@ void AppearanceManager::applyGlobalTheme(KeyFile &theme, const QString &themeNam
         }
     };
 
-    // 如果是用户自定义主题, 切换外观时只单独更新外观选项
-    if (themePath.endsWith("custom")) {
-        setGlobalItem("AppTheme", TYPEGTK);
-        setGlobalItem("ActiveColor", TYPEACTIVECOLOR);
-        m_globalThemeUpdating = false;
-        return;
-    }
-
-    setGlobalFile("Wallpaper", TYPEWALLPAPER);
+    if (!m_setDefaulting || m_property->wallpaperURls->isEmpty())
+        setGlobalFile("Wallpaper", TYPEWALLPAPER);
+    
     setGlobalFile("LockBackground", TYPEGREETERBACKGROUND);
     setGlobalItem("IconTheme", TYPEICON);
     setGlobalItem("CursorTheme", TYPECURSOR);
@@ -1733,6 +1568,22 @@ bool AppearanceManager::isSkipSetWallpaper(const QString &themePath)
     return false;
 }
 
+bool AppearanceManager::checkWallpaperLockedStatus()
+{
+    if (QFileInfo::exists("/var/lib/deepin/permission-manager/wallpaper_locked")) {
+        QDBusInterface notify("org.freedesktop.Notifications", "/org/freedesktop/Notifications", "org.freedesktop.Notifications");
+        notify.asyncCall(QString("Notify"),
+                         QString("org.deepin.dde.control-center"),   // title
+                         static_cast<uint>(0),
+                         QString("preferences-system"),   // icon
+                         QObject::tr("This system wallpaper is locked. Please contact your admin."),
+                         QString(), QStringList(), QVariantMap(), 5000);
+        qInfo() << "wallpaper is locked..";
+        return true;
+    }
+    return false;
+}
+
 void AppearanceManager::updateCustomTheme(const QString &type, const QString &value)
 {
     if (!m_globalThemeUpdating) {
@@ -1822,6 +1673,7 @@ void AppearanceManager::initGlobalTheme()
             break;
         }
     }
+    m_setDefaulting = true;
     if (!bFound) {
         for (auto theme : globalList) {
             if (theme->getId() == DEFAULTGLOBALTHEME) {
@@ -1843,6 +1695,7 @@ void AppearanceManager::initGlobalTheme()
         if (m_currentGlobalTheme.isEmpty())
             doSetGlobalTheme(m_property->globalTheme);
     }
+    m_setDefaulting = false;
 }
 
 void AppearanceManager::doSetCurrentWorkspaceBackground(const QString &uri)
@@ -1863,6 +1716,9 @@ QString AppearanceManager::doGetCurrentWorkspaceBackground()
 
 void AppearanceManager::doSetCurrentWorkspaceBackgroundForMonitor(const QString &uri, const QString &strMonitorName)
 {
+    if (checkWallpaperLockedStatus()) {
+        return;
+    }
     QString strIndex = QString::number(getCurrentDesktopIndex());
     if (strIndex == "") {
         qWarning() << "error getting current desktop index through wm";
@@ -1872,6 +1728,19 @@ void AppearanceManager::doSetCurrentWorkspaceBackgroundForMonitor(const QString
     if (auto value = PhaseWallPaper::setWallpaperUri(strIndex, strMonitorName, uri); value.has_value()) {
         m_wallpaperConfig = value.value();
     }
+
+    // TODO delete, 临时适配Treeland
+    if (utils::isTreeland()) {
+        QString arg = QString("personalization/wallpaper?url=%1").arg(uri);
+        DDBusSender()
+                .service("org.deepin.dde.ControlCenter1")
+                .interface("org.deepin.dde.ControlCenter1")
+                .path("/org/deepin/dde/ControlCenter1")
+                .method("ShowPage")
+                .arg(arg)
+                .call();
+    }
+
     doUpdateWallpaperURIs();
     return;
 }
@@ -1889,8 +1758,23 @@ QString AppearanceManager::doGetCurrentWorkspaceBackgroundForMonitor(const QStri
 
 void AppearanceManager::doSetWorkspaceBackgroundForMonitor(const int &index, const QString &strMonitorName, const QString &uri)
 {
+    if (checkWallpaperLockedStatus()) {
+        return;
+    }
+ 
     if (auto value = PhaseWallPaper::setWallpaperUri(QString::number(index), strMonitorName, uri); value.has_value()) {
         m_wallpaperConfig = value.value();
+    }
+        // TODO delete, 临时适配Treeland
+    if (utils::isTreeland()) {
+        QString arg = QString("personalization/wallpaper?url=%1").arg(uri);
+        DDBusSender()
+                .service("org.deepin.dde.ControlCenter1")
+                .interface("org.deepin.dde.ControlCenter1")
+                .path("/org/deepin/dde/ControlCenter1")
+                .method("ShowPage")
+                .arg(arg)
+                .call();
     }
     doUpdateWallpaperURIs();
 }
@@ -1907,79 +1791,19 @@ void AppearanceManager::doSetDTKSizeMode(int value) {
     }
 }
 
+void AppearanceManager::doSetQtScrollBarPolicy(int value)
+{
+    if (value != m_property->qtScrollBarPolicy) {
+        setQtScrollBarPolicy(value);
+        m_dbusProxy->SetInteger("Qt/ScrollBarPolicy",value);
+    }
+}
+
 QString AppearanceManager::getActiveColors()
 {
     return m_settingDconfig.value(DACTIVECOLORS).toString();
 }
 
-void AppearanceManager::autoChangeBg(QString monitorSpace, QDateTime date)
-{
-    qDebug() << "autoChangeBg: " << monitorSpace << ", " << date;
-
-    if (m_wsLoopMap.count(monitorSpace) == 0) {
-        return;
-    }
-
-    QString file = m_wsLoopMap[monitorSpace]->getNext();
-    if (file.isEmpty()) {
-        qDebug() << "file is empty";
-        return;
-    }
-
-    QString strIndex = QString::number(getCurrentDesktopIndex());
-
-    QStringList monitorlist = monitorSpace.split("&&");
-    if (monitorlist.size() != 2) {
-        qWarning() << "monitorSpace format error";
-        return;
-    }
-
-    if (strIndex == monitorlist.at(1)) {
-        doSetMonitorBackground(monitorlist.at(0), file);
-    }
-
-    saveWSConfig(monitorSpace, date);
-}
-
-bool AppearanceManager::changeBgAfterLogin(QString monitorSpace)
-{
-    QString runDir = utils::GetUserRuntimeDir();
-
-    QFile file("/proc/self/sessionid");
-    if (!file.open(QIODevice::ReadOnly)) {
-        qWarning() << "open /proc/self/sessionid fail";
-        return false;
-    }
-
-    QString currentSessionId = file.readAll();
-    currentSessionId = currentSessionId.simplified();
-
-    bool needChangeBg = false;
-    runDir = runDir + "/dde-daemon-wallpaper-slideshow-login" + "/" + monitorSpace;
-    QFile fileTemp(runDir);
-
-    if (!file.exists()) {
-        needChangeBg = true;
-    } else if (!fileTemp.open(QIODevice::ReadOnly)) {
-        qWarning() << "open " << runDir << " fail";
-        return false;
-    } else {
-        if (currentSessionId != fileTemp.readAll().simplified()) {
-            needChangeBg = true;
-        }
-    }
-
-    if (needChangeBg) {
-        autoChangeBg(monitorSpace, QDateTime::currentDateTimeUtc());
-        fileTemp.write(currentSessionId.toLatin1());
-    }
-
-    file.close();
-    fileTemp.close();
-
-    return true;
-}
-
 bool AppearanceManager::setDQtTheme(QStringList key, QStringList value)
 {
     if (key.length() != value.length()) {
@@ -2001,21 +1825,6 @@ bool AppearanceManager::setDQtTheme(QStringList key, QStringList value)
     return true;
 }
 
-bool AppearanceManager::saveWSConfig(QString monitorSpace, QDateTime date)
-{
-    WallpaperLoopConfigManger configManger;
-
-    QString fileName = utils::GetUserConfigDir() + "/deepin/dde-daemon/appearance/wallpaper-slideshow.json";
-    configManger.loadWSConfig(fileName);
-
-    if (m_wsLoopMap.count(monitorSpace) != 0) {
-        configManger.setShowed(monitorSpace, m_wsLoopMap[monitorSpace]->getShowed());
-    }
-    configManger.setLastChange(monitorSpace, date);
-
-    return configManger.save(fileName);
-}
-
 QString AppearanceManager::marshal(const QVector<QSharedPointer<Theme>> &themes)
 {
     QJsonDocument doc;
@@ -2083,3 +1892,24 @@ QString AppearanceManager::marshal(const QVector<QSharedPointer<FontsManager::Fa
     doc.setArray(arr);
     return doc.toJson(QJsonDocument::Compact);
 }
+
+void AppearanceManager::initGlobalOverrideConfig()
+{
+    m_globalThemeOverrideMap.clear();
+    const auto &overrideList = m_settingDconfig.value("globalThemeOverride").value<QVariantList>();
+    for (const auto &overrideItem : overrideList) {
+        const auto &overrideMap = overrideItem.toMap();
+        auto id = overrideMap.value("id").toString();
+        auto overrideVecMap = overrideMap.value("override").value<QVariantList>();
+        for (const auto &overrideValue : overrideVecMap) {
+            const auto &overrideMap = overrideValue.toMap();
+            GlobalThemeOverride itemOverride;
+            itemOverride.section = overrideMap.value("section").toString();
+            itemOverride.key = overrideMap.value("key").toString();
+            itemOverride.value = overrideMap.value("value").toString();
+            m_globalThemeOverrideMap[id].append(itemOverride);
+
+            qDebug() << "add global theme override:" << id << itemOverride.section << itemOverride.key << itemOverride.value;
+        }
+    }
+}
