@@ -9,7 +9,6 @@
 #include "modules/subthemes/subthemes.h"
 #include "modules/fonts/fontsmanager.h"
 #include "dbus/scaleFactors.h"
-#include "wallpaperscheduler.h"
 
 #include <QObject>
 #include <QDebug>
@@ -18,7 +17,6 @@
 #include <QMap>
 #include <QTimerEvent>
 #include <QTimer>
-#include <QGSettings>
 #include <QJsonArray>
 
 #include <dbus/appearanceproperty.h>
@@ -42,6 +40,12 @@ class AppearanceManager : public QObject
         QString Monospace;
     };
 
+    struct GlobalThemeOverride{
+        QString section;
+        QString key;
+        QString value;
+    };
+
 public:
     explicit AppearanceManager(AppearanceProperty *prop, QObject *parent = nullptr);
     ~AppearanceManager();
@@ -79,6 +83,7 @@ public:
     bool doSetGreeterBackground(QString value);
     QString doGetWallpaperSlideShow(QString monitorName);
     void doSetDTKSizeMode(int value);
+    void doSetQtScrollBarPolicy(int value);
     double getScaleFactor();
     ScaleFactors getScreenScaleFactors();
     bool setScaleFactor(double scale);
@@ -90,7 +95,6 @@ public:
     void doSetByType(const QString& type,const QString& value);
     QString doSetMonitorBackground(const QString& monitorName,const QString& imageGile);
     bool doSetWallpaperSlideShow(const QString &monitorName,const QString &wallpaperSlideShow);
-    bool doSetWsLoop(const QString& monitorName,const QString& file);
     QString doThumbnail(const QString &type, const QString &name);
     void doSetCurrentWorkspaceBackground(const QString &uri);
     QString doGetCurrentWorkspaceBackground();
@@ -121,6 +125,8 @@ public:
     int getWorkspaceCount();
     void timerEvent(QTimerEvent *event) override;
 
+    inline QHash<QString, QVector<GlobalThemeOverride>> getGlobalOverride() const { return m_globalThemeOverrideMap; }
+
 public Q_SLOTS:
     void handleWmWorkspaceCountChanged(int count);
     void handleWmWorkspaceSwithched(int from,int to);
@@ -132,20 +138,15 @@ public Q_SLOTS:
     void handlethemeFileChange(QString theme);
     void handleXsettingDConfigChange(QString key);
     void handleSettingDConfigChange(QString key);
-    void handleWrapBgDConfigChange(QString key);
-    void handleGnomeBgDConfigChange(QString key);
     void handleDetectSysClockTimeOut();
     void handleUpdateToCustom(const QString &mode);
     void handleGlobalThemeChangeTimeOut();
     void updateMonitorMap();
-    void handlePrepareForSleep(bool sleep);
-    void onOpacityTriggerTimeout();
 
 private:
     void initCoordinate();
     void initUserObj();
     void initCurrentBgs();
-    void initWallpaperSlideshow();
     void initDtkSizeMode();
     void iso6709Parsing(QString city, QString coordinates);
     void doUpdateWallpaperURIs();
@@ -155,20 +156,15 @@ private:
     void resetThemeAutoTimer();
     void updateThemeAuto(bool enable);
     void enableDetectSysClock(bool enable);
-    void updateWSPolicy(QString policy);
-    void loadWSConfig();
     QDateTime getThemeAutoChangeTime(QDateTime date, double latitude, double longitude);
 
-    void autoChangeBg(QString monitorSpace, QDateTime date);
-    bool changeBgAfterLogin(QString monitorSpace);
     bool setDQtTheme(QStringList key,QStringList value);
-    bool saveWSConfig(QString monitorSpace, QDateTime date);
     QString marshal(const QVector<QSharedPointer<Theme>>& themes);
     QString marshal(const QVector<Background>& backgrounds);
     QString marshal(const QStringList& strs);
     QString marshal(const QVector<QSharedPointer<FontsManager::Family>>& strs);
     int getCurrentDesktopIndex();
-    void applyGlobalTheme(KeyFile &theme, const QString &themeName, const QString &defaultTheme, const QString &themePath);
+    void applyGlobalTheme(KeyFile &theme, const QString &themeName, const QString &defaultTheme, const QString &themePath, const QString &themeId);
 
     void updateCustomTheme(const QString &type, const QString &value);
     bool isBgInUse(const QString &file);
@@ -176,6 +172,8 @@ private:
     QString getWallpaperUri(const QString &index, const QString &monitorName);
     void initGlobalTheme();
     bool isSkipSetWallpaper(const QString &themePath);
+    bool checkWallpaperLockedStatus();
+    void initGlobalOverrideConfig();
 
 Q_SIGNALS:
     void Changed(const QString &ty, const QString &value);
@@ -186,9 +184,7 @@ private: // PROPERTIES
 
 private:
     DConfig                                          m_settingDconfig;
-    QSharedPointer<QGSettings>                       m_xSetting;
-    QSharedPointer<QGSettings>                       m_wrapBgSetting;
-    QSharedPointer<QGSettings>                       m_gnomeBgSetting;
+    QSharedPointer<DConfig>                          m_XSettingsDconfig;
     QSharedPointer<AppearanceDBusProxy>              m_dbusProxy;
     QSharedPointer<Subthemes>                        m_subthemes;
     QSharedPointer<Backgrounds>                      m_backgrounds;
@@ -210,14 +206,12 @@ private:
     QTimer                                           m_themeAutoTimer;     // 自动切换深浅主题定时器
     qint64                                           m_detectSysClockStartTime;
     QString                                          m_zone;
-    QMap<QString,QSharedPointer<WallpaperScheduler>> m_wsSchedulerMap;
-    QMap<QString,QSharedPointer<WallpaperLoop>>      m_wsLoopMap;
     CustomTheme                                      *m_customTheme;
     bool                                             m_globalThemeUpdating;
     QString                                          m_currentGlobalTheme; // 当前主题，globalTheme+.light/.dark
     QJsonArray                                       m_wallpaperConfig; // store the config
-    QTimer                                           *m_opacityTriggerTimer; // 定时器限制opacity的变化速率，防止卡顿
-    double                                           m_tmpOpacity;
+    bool                                             m_setDefaulting;
+    QHash<QString, QVector<GlobalThemeOverride>>     m_globalThemeOverrideMap;
 };
 
 #endif // APPEARANCEMANAGER_H
